<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="or">
<context>
    <name>CardWidget</name>
    <message>
        <location filename="../cardwidget.ui" line="14"/>
        <source>Form</source>
        <translation>ଫର୍ମ</translation>
    </message>
    <message>
        <location filename="../cardwidget.ui" line="29"/>
        <source>Card Name</source>
        <translation>କାର୍ଡ଼ ନାମ</translation>
    </message>
    <message>
        <location filename="../cardwidget.ui" line="47"/>
        <source>Profile:</source>
        <translation>ରୂପରେଖ:</translation>
    </message>
    <message>
        <location filename="../cardwidget.cc" line="67"/>
        <source>pa_context_set_card_profile_by_index() failed</source>
        <translation>pa_context_set_card_profile_by_index() ବିଫଳ ହୋଇଛି</translation>
    </message>
</context>
<context>
    <name>Channel</name>
    <message>
        <location filename="../channel.cc" line="89"/>
        <source>%1% (%2dB)</source>
        <comment>volume slider label [X% (YdB)]</comment>
        <translation>%୧%(%୨ଡ଼ି.ବିି.)</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="93"/>
        <source>%1%</source>
        <comment>volume slider label [X%]</comment>
        <translation>%୧%</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="160"/>
        <source>&lt;small&gt;Silence&lt;/small&gt;</source>
        <translation>&lt;small&gt;ନିରବତା&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="160"/>
        <source>&lt;small&gt;Min&lt;/small&gt;</source>
        <translation>&lt;small&gt;ସର୍ବନିମ୍ନ&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="162"/>
        <source>&lt;small&gt;100% (0dB)&lt;/small&gt;</source>
        <translation>&lt;small&gt;୧୦୦%(୦ଡ଼ିବି)&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../channel.cc" line="165"/>
        <source>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</source>
        <translation>&lt;small&gt;&lt;i&gt;ଆଧାର&lt;/i&gt;&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>ChannelWidget</name>
    <message>
        <location filename="../channelwidget.ui" line="14"/>
        <source>Form</source>
        <translation>ଫର୍ମ</translation>
    </message>
    <message>
        <location filename="../channelwidget.ui" line="20"/>
        <source>&lt;b&gt;left-front&lt;/b&gt;</source>
        <translation>&lt;b&gt;ବାମ-ସାମ୍ନା&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../channelwidget.ui" line="34"/>
        <source>&lt;small&gt;50%&lt;/small&gt;</source>
        <translation>&lt;small&gt;୫୦%&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>DeviceWidget</name>
    <message>
        <location filename="../devicewidget.ui" line="14"/>
        <source>Form</source>
        <translation>ଫର୍ମ</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="36"/>
        <source>Device Title</source>
        <translation>ଯନ୍ତ୍ର ଶୀର୍ଷକ</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="56"/>
        <source>Mute audio</source>
        <translation>ମୌନ ଧ୍ବନି</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="69"/>
        <source>Lock channels together</source>
        <translation>ଚ୍ୟାନେଲ୍ ମାନଂକୁ ଏକା ସାଂଗରେ ବନ୍ଦ କର</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="85"/>
        <source>Set as fallback</source>
        <translation>ପଛରେ ପଡିବା ପାଇଁ  ସ୍ଥିର କରିବା</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="103"/>
        <source>&lt;b&gt;Port:&lt;/b&gt;</source>
        <translation>&lt;b&gt;ସଂଯୋଗିକୀ:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="126"/>
        <source>Show advanced options</source>
        <translation>ଅଗ୍ରୀମ ବିକଳ୍ପ ଦେଖାଅ</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="172"/>
        <source>PCM</source>
        <translation>ପି.ସି.ଏମ.</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="182"/>
        <source>AC3</source>
        <translation>ଏ.ସି.୩</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="189"/>
        <source>EAC3</source>
        <translation>ଇଏ.ସି.୩</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="196"/>
        <source>DTS</source>
        <translation>ଡି.ଟି.ଏସ୍.</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="203"/>
        <source>MPEG</source>
        <translation>ଏ.ମ.ଇ.ଯୀ.</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="210"/>
        <source>AAC</source>
        <translation>ଏ.ଏ.ସି.</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="238"/>
        <source>&lt;b&gt;Latency offset:&lt;/b&gt;</source>
        <translation>&lt;b&gt;ସୁପ୍ତ ଅଫସେଟ&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../devicewidget.ui" line="245"/>
        <source> ms</source>
        <translation> ଏମ.ଏସ.</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="41"/>
        <source>Rename device...</source>
        <translation>ଯନ୍ତ୍ରର ନାମ  ପରିର୍ବତ୍ତନ...</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="155"/>
        <source>pa_context_set_port_latency_offset() failed</source>
        <translation>pa_context_set_port_latency_offset() ବିଫଳିତ</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="226"/>
        <source>Sorry, but device renaming is not supported.</source>
        <translation>କ୍ଷମା କରନ୍ତୁ, କିନ୍ତୁ  ଯନ୍ତ୍ର ନାମ  ପରିର୍ବତ୍ତନ ଉପଲବ୍ଧ ନୁହେଁ |</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="227"/>
        <source>You need to load module-device-manager in the PulseAudio server in order to rename devices</source>
        <translation>ଆପଣଙ୍କୁ module-device-manager କୁ PulseAudio ସର୍ଭର ରେ ଧାରଣ କରାଇବାକୁ ପଡିବ, ଯନ୍ତ୍ରର ନାମ ପରିବର୍ତନ କରିବା ପାଇଁ</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="233"/>
        <source>Rename device %1 to:</source>
        <translation>%୧ ଯନ୍ତ୍ରର ନାମ ପରିର୍ବତ୍ତନ କରାଯିବ:</translation>
    </message>
    <message>
        <location filename="../devicewidget.cc" line="240"/>
        <source>pa_ext_device_manager_set_device_description() failed</source>
        <translation>pa_ext_device_manager_set_device_description() ବିଫଳିତ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Volume Control</source>
        <translation>ଧ୍ବନିଶକ୍ତି ନିୟନ୍ତ୍ରଣ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="28"/>
        <source>&amp;Playback</source>
        <translation>&amp;ପୁନଃପ୍ରଦର୍ଶନ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>&lt;i&gt;No application is currently playing audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;ବର୍ତ୍ତମାନ କୌଣସି ପ୍ରୋଗ୍ରାମ ଧ୍ୱନି ଚଲାଉନାହିଁ।&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="66"/>
        <location filename="../mainwindow.ui" line="131"/>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Show:</source>
        <translation>ଦେଖାଅ:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <location filename="../mainwindow.ui" line="139"/>
        <source>All Streams</source>
        <translation>ସମସ୍ତ ଧାରା</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <location filename="../mainwindow.ui" line="144"/>
        <source>Applications</source>
        <translation>ଉପକରଣ ମାନ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <location filename="../mainwindow.ui" line="149"/>
        <source>Virtual Streams</source>
        <translation>କଳ୍ପିତ ଧାରାମାନ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>&amp;Recording</source>
        <translation>&amp;ଅଭିଲେଖନୀ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&lt;i&gt;No application is currently recording audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;ବର୍ତ୍ତମାନ କୌଣସି ପ୍ରୋଗ୍ରାମ ଧ୍ୱନି ଅଭିଲେଖନୀ କରୁନାହିଁ |&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>&amp;Output Devices</source>
        <translation>&amp;ନିର୍ଗମ ଉପକରଣଗୁଡ଼ିକ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>&lt;i&gt;No output devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;କୌଣସି ନିର୍ଗମ ଉପକରଣ ଉପଲବ୍ଧ ନାହିଁ&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <source>All Output Devices</source>
        <translation>ସମସ୍ତ ନିର୍ଗମ ଧାରା</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Hardware Output Devices</source>
        <translation>ହାର୍ଡ଼ୱେର ନିର୍ଗମ ଯନ୍ତ୍ରମାନ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>Virtual Output Devices</source>
        <translation>ନିର୍ଗମ ନିର୍ଗମ ଯନ୍ତ୍ରମାନ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <source>&amp;Input Devices</source>
        <translation>&amp;ନିବେଶ ଉପକରଣଗୁଡ଼ିକ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&lt;i&gt;No input devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;କୌଣସି ନିବେଶ ଉପକରଣ ଉପଲବ୍ଧ ନାହିଁ&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>All Input Devices</source>
        <translation>ସମସ୍ତ ନିବେଶ ଯନ୍ତ୍ରମାନ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>All Except Monitors</source>
        <translation>ମୋନୀଟର ମାନଂକ ଛଡ଼ା ସବୁ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>Hardware Input Devices</source>
        <translation>ହାର୍ଡ଼ୱେର ନିବେଶ ଯନ୍ତ୍ରମାନ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>Virtual Input Devices</source>
        <translation>କଳ୍ପିତ ନିବେଶ ଯନ୍ତ୍ରମାନ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Monitors</source>
        <translation>ମୋନୀଟରମାନ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>&amp;Configuration</source>
        <translation>&amp;ସଂରଚନା</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>&lt;i&gt;No cards available for configuration&lt;/i&gt;</source>
        <translation>&lt;i&gt;ସଂରଚନା ପାଇଁ କୌଣସି କାର୍ଡ ଉପଲବ୍ଧ ନାହିଁ&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>Show volume meters</source>
        <translation>ଧ୍ଵନି ମାପ ଉପକରଣ ଦେଖାଅ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="347"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="159"/>
        <source> (plugged in)</source>
        <translation> (ଲଗା ହୋଇଛି)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="163"/>
        <location filename="../mainwindow.cc" line="257"/>
        <source> (unavailable)</source>
        <translation> (ଉପଲବ୍ଧ ନୁହେଁ)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="165"/>
        <location filename="../mainwindow.cc" line="254"/>
        <source> (unplugged)</source>
        <translation> (ଖୋଲା ଅଛି)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="388"/>
        <source>Failed to read data from stream</source>
        <translation>ଧାରାରୁ ତଥ୍ୟ ପଢ଼ିବାରେ ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="432"/>
        <source>Peak detect</source>
        <translation>ଶିଖର ଚିହ୍ନାପଡ଼ିଛି</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="433"/>
        <source>Failed to create monitoring stream</source>
        <translation>ପ୍ରଦର୍ଶିକା ଧାରାକୁ ନିର୍ମାଣ କରିବାରେ ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="448"/>
        <source>Failed to connect monitoring stream</source>
        <translation>ପ୍ରଦର୍ଶିକା ଧାରା ସହିତ ସଂଯୋଗ କରିବାରେ ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="587"/>
        <source>Ignoring sink-input due to it being designated as an event and thus handled by the Event widget</source>
        <translation>sink-input କୁ ଅଦେଖା କରାଯାଉଛି କାରଣ ଏହା ଏକ ଘଟଣା ଭାବେ ଅଭିହିତ ଅଛି ତେଣୁ ଏହା ଘଟଣା ଉପକରଣ ଦ୍ୱାରା ପରିଚାଳଣ କରାଯାଉଛି</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="759"/>
        <source>System Sounds</source>
        <translation>ତନ୍ତ୍ର ଧ୍ୱନିି</translation>
    </message>
    <message>
        <location filename="../mainwindow.cc" line="1089"/>
        <source>Establishing connection to PulseAudio. Please wait...</source>
        <translation>ପଲସଅଡିଓ ସହ ସଂପର୍କ ଆରମ୍ଭ କରାଯାଉଛି| କୃପା କରି ଅପେକ୍ଷା କରନ୍ତୁ...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../pavucontrol.cc" line="66"/>
        <source>Error</source>
        <translation>ତ୍ରୁଟି</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="87"/>
        <source>Card callback failure</source>
        <translation>କାର୍ଡ଼ କଲବ୍ୟାକ ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="110"/>
        <source>Sink callback failure</source>
        <translation>ସିଙ୍କ କଲବ୍ୟାକ ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="133"/>
        <source>Source callback failure</source>
        <translation>ଉତ୍ସ କଲବ୍ୟାକ ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="152"/>
        <source>Sink input callback failure</source>
        <translation>ସିଙ୍କ ନିବେଶ କଲବ୍ୟାକ ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="171"/>
        <source>Source output callback failure</source>
        <translation>ଉତ୍ସ ନିର୍ଗମ କଲବ୍ୟାକ ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="211"/>
        <source>Client callback failure</source>
        <translation>ଗ୍ରାହକ କଲବ୍ୟାକ ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="227"/>
        <source>Server info callback failure</source>
        <translation>ସର୍ଭର ସୂଚନା କଲବ୍ୟାକ ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="245"/>
        <location filename="../pavucontrol.cc" line="542"/>
        <source>Failed to initialize stream_restore extension: %s</source>
        <translation>stream_restore ଅନୁଲଗ୍ନକୁ ଆରମ୍ଭ କରିବାରେ ବିଫଳ: %s</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="263"/>
        <source>pa_ext_stream_restore_read() failed</source>
        <translation>pa_ext_stream_restore_read() ବିଫଳ ହୋଇଛି</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="281"/>
        <location filename="../pavucontrol.cc" line="556"/>
        <source>Failed to initialize device restore extension: %s</source>
        <translation>ଯନ୍ତ୍ର ପୁନଃସ୍ଥାପନା ଅନୁଲଗ୍ନ ପ୍ରାରମ୍ଭିକରଣରେ ଅସଫଳ: %s</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="302"/>
        <source>pa_ext_device_restore_read_sink_formats() failed</source>
        <translation>pa_ext_device_restore_read_sink_formats() ବିଫଳିତ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="320"/>
        <location filename="../pavucontrol.cc" line="569"/>
        <source>Failed to initialize device manager extension: %s</source>
        <translation>ଯନ୍ତ୍ର ପରିଚାଳକ ଅନୁଲଗ୍ନ ପ୍ରାରମ୍ଭିକରଣରେ ଅସଫଳ: %s</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="339"/>
        <source>pa_ext_device_manager_read() failed</source>
        <translation>pa_ext_device_manager_read() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="356"/>
        <source>pa_context_get_sink_info_by_index() failed</source>
        <translation>pa_context_get_sink_info_by_index() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="369"/>
        <source>pa_context_get_source_info_by_index() failed</source>
        <translation>pa_context_get_source_info_by_index() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="382"/>
        <location filename="../pavucontrol.cc" line="395"/>
        <source>pa_context_get_sink_input_info() failed</source>
        <translation>pa_context_get_sink_input_info() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="408"/>
        <source>pa_context_get_client_info() failed</source>
        <translation>pa_context_get_client_info() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="418"/>
        <location filename="../pavucontrol.cc" line="483"/>
        <source>pa_context_get_server_info() failed</source>
        <translation>pa_context_get_server_info() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="431"/>
        <source>pa_context_get_card_info_by_index() failed</source>
        <translation>pa_context_get_card_info_by_index() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="474"/>
        <source>pa_context_subscribe() failed</source>
        <translation>pa_context_subscribe() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="490"/>
        <source>pa_context_client_info_list() failed</source>
        <translation>pa_context_client_info_list() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="497"/>
        <source>pa_context_get_card_info_list() failed</source>
        <translation>pa_context_get_card_info_list() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="504"/>
        <source>pa_context_get_sink_info_list() failed</source>
        <translation>pa_context_get_sink_info_list() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="511"/>
        <source>pa_context_get_source_info_list() failed</source>
        <translation>pa_context_get_source_info_list() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="518"/>
        <source>pa_context_get_sink_input_info_list() failed</source>
        <translation>pa_context_get_sink_input_info_list() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="525"/>
        <source>pa_context_get_source_output_info_list() failed</source>
        <translation>pa_context_get_source_output_info_list() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="584"/>
        <location filename="../pavucontrol.cc" line="635"/>
        <source>Connection failed, attempting reconnect</source>
        <translation>ଯୋଗାଯୋଗ ଅସଫଳ, ପୁନଃ ଯୋଗାଯୋଗ ପାଇଁ ଚେଷ୍ଟା କରାଯାଉଛି</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="607"/>
        <location filename="../pavucontrol.cc" line="664"/>
        <source>PulseAudio Volume Control</source>
        <translation>PulseAudio ଧ୍ୱନି ଶକ୍ତି ନିୟନ୍ତ୍ରଣ</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="622"/>
        <source>Connection to PulseAudio failed. Automatic retry in 5s

In this case this is likely because PULSE_SERVER in the Environment/X11 Root Window Properties
or default-server in client.conf is misconfigured.
This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.
If this is the case, then PulseAudio should autospawn again, or if this is not configured you should
run start-pulseaudio-x11 manually.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="672"/>
        <source>Select a specific tab on load.</source>
        <translation>ଏକ ନିର୍ଦ୍ଧିଷ୍ଟ ଟ୍ୟାବ୍ କୁ ଆରମ୍ଭରେ ବାଛନ୍ତୁ |</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="675"/>
        <source>Retry forever if pa quits (every 5 seconds).</source>
        <translation>ସବୁବେଳେ ଚେଷ୍ଟା କର ଯଦି ପା ବନ୍ଦ ହେଉଛି (ପ୍ରତି ୫ ମୁହୁର୍ତରେ) |</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="678"/>
        <source>Maximize the window.</source>
        <translation>ଉଇଣ୍ଡୋ କୁ  ବୃହତ୍ତମନ କର |</translation>
    </message>
    <message>
        <location filename="../pavucontrol.cc" line="703"/>
        <source>Fatal Error: Unable to connect to PulseAudio</source>
        <translation>ଗୁରୁତର ତ୍ରୁଟି: ପଲସଅଡିଓ ସହ ଯୋଗାଯୋଗ କରିବାରେ ଅସଫଳ</translation>
    </message>
</context>
<context>
    <name>RoleWidget</name>
    <message>
        <location filename="../rolewidget.cc" line="59"/>
        <source>pa_ext_stream_restore_write() failed</source>
        <translation>pa_ext_stream_restore_write() ଅସଫଳ</translation>
    </message>
</context>
<context>
    <name>SinkInputWidget</name>
    <message>
        <location filename="../sinkinputwidget.cc" line="36"/>
        <source>on</source>
        <translation>ଆରମ୍ଭ</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="39"/>
        <source>Terminate Playback</source>
        <translation>ପୁନଃପ୍ରଦର୍ଶନ କୁ ସମାପ୍ତ କର</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="53"/>
        <source>Unknown output</source>
        <translation>ଅଜଣା ଫଳାଫଳ</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="64"/>
        <source>pa_context_set_sink_input_volume() failed</source>
        <translation>pa_context_set_sink_input_volume() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="79"/>
        <source>pa_context_set_sink_input_mute() failed</source>
        <translation>pa_context_set_sink_input_mute() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="89"/>
        <source>pa_context_kill_sink_input() failed</source>
        <translation>pa_context_kill_sink_input() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sinkinputwidget.cc" line="114"/>
        <source>pa_context_move_sink_input_by_index() failed</source>
        <translation>pa_context_move_sink_input_by_index() ଅସଫଳ</translation>
    </message>
</context>
<context>
    <name>SinkWidget</name>
    <message>
        <location filename="../sinkwidget.cc" line="81"/>
        <source>pa_context_set_sink_volume_by_index() failed</source>
        <translation>pa_context_set_sink_volume_by_index() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="96"/>
        <source>pa_context_set_sink_mute_by_index() failed</source>
        <translation>pa_context_set_sink_mute_by_index() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="110"/>
        <source>pa_context_set_default_sink() failed</source>
        <translation>pa_context_set_default_sink() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="126"/>
        <source>pa_context_set_sink_port_by_index() failed</source>
        <translation>pa_context_set_sink_port_by_index() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sinkwidget.cc" line="166"/>
        <source>pa_ext_device_restore_save_sink_formats() failed</source>
        <translation>pa_ext_device_restore_save_sink_formats() ଅସଫଳ</translation>
    </message>
</context>
<context>
    <name>SourceOutputWidget</name>
    <message>
        <location filename="../sourceoutputwidget.cc" line="35"/>
        <source>from</source>
        <translation>ଠାରୁ</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="39"/>
        <source>Terminate Recording</source>
        <translation>ଅଭିଲେଖନୀ ସମାପ୍ତ କର</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="60"/>
        <source>Unknown input</source>
        <translation>ଅଜଣା ନିବେଶ</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="72"/>
        <source>pa_context_set_source_output_volume() failed</source>
        <translation>pa_context_set_source_output_volume() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="87"/>
        <source>pa_context_set_source_output_mute() failed</source>
        <translation>pa_context_set_source_output_mute() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="98"/>
        <source>pa_context_kill_source_output() failed</source>
        <translation>pa_context_kill_source_output() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sourceoutputwidget.cc" line="125"/>
        <source>pa_context_move_source_output_by_index() failed</source>
        <translation>pa_context_move_source_output_by_index() ଅସଫଳ</translation>
    </message>
</context>
<context>
    <name>SourceWidget</name>
    <message>
        <location filename="../sourcewidget.cc" line="35"/>
        <source>pa_context_set_source_volume_by_index() failed</source>
        <translation>pa_context_set_source_volume_by_index() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sourcewidget.cc" line="50"/>
        <source>pa_context_set_source_mute_by_index() failed</source>
        <translation>pa_context_set_source_mute_by_index() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sourcewidget.cc" line="64"/>
        <source>pa_context_set_default_source() failed</source>
        <translation>pa_context_set_default_source() ଅସଫଳ</translation>
    </message>
    <message>
        <location filename="../sourcewidget.cc" line="80"/>
        <source>pa_context_set_source_port_by_index() failed</source>
        <translation>pa_context_set_source_port_by_index() ଅସଫଳ</translation>
    </message>
</context>
<context>
    <name>StreamWidget</name>
    <message>
        <location filename="../streamwidget.ui" line="14"/>
        <source>Form</source>
        <translation>ଫର୍ମ</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="32"/>
        <source>Device Title</source>
        <translation>ଯନ୍ତ୍ର ନାମ</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="52"/>
        <source>direction</source>
        <translation>ଦିଗ</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="59"/>
        <source>device</source>
        <translation>ଯନ୍ତ୍ର</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="66"/>
        <source>Mute audio</source>
        <translation>ଧ୍ବନିକୁ ମୌନ କର</translation>
    </message>
    <message>
        <location filename="../streamwidget.ui" line="79"/>
        <source>Lock channels together</source>
        <translation>ଚ୍ୟାନେଲ୍ ମାନଂକୁ ଏକା ସାଂଗରେ ବନ୍ଦ କର</translation>
    </message>
    <message>
        <location filename="../streamwidget.cc" line="34"/>
        <source>Terminate</source>
        <translation>ସମାପ୍ତ କର</translation>
    </message>
</context>
</TS>
